@@ -82,7 +82,7 @@ NewTransferDialog::NewTransferDialog(QWidget *parent)
     connect(ui.groupComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(setDefaultDestination()));
 
     connect(ui.urlRequester, SIGNAL(textChanged(QString)), this, SLOT(setDefaultDestination()));
-    connect(ui.destRequester, SIGNAL(textChanged(QString)), this, SLOT(inputTimer())); //FIXME for some reason this signal never seems to be emitted
+    connect(ui.destRequester, SIGNAL(textChanged(QString)), this, SLOT(inputTimer()));
     connect(ui.urlRequester, SIGNAL(textChanged(QString)), this, SLOT(inputTimer()));
     connect(ui.listWidget, SIGNAL(itemChanged(QListWidgetItem*)), this, SLOT(inputTimer()));
     connect(this, SIGNAL(finished(int)), this, SLOT(slotFinished(int)));
@@ -402,9 +402,11 @@ void NewTransferDialog::dialogAccepted()
 {
     qCDebug(KGET_DEBUG) << "Dialog accepted.";
 
-    //FIXME checkInput() shouldn't have to be called here, it should actually be called whenever the text in the input fields changes.
-    // For some reason that doesn't work for the destination field though, so call it explicitly here as a workaround for now, to make the choice be respected. (checkInput() sets m_destination accordingly)
+#if KIO_VERSION < QT_VERSION_CHECK(5, 42, 0)
+    // checkInput() shouldn't have to be called here, it should actually be called whenever the text in the input fields changes.
+    // Due to a bug in KUrlRequester (that's fixed in KIO 5.42), this doesn't work for the destination field though, so call it explicitly here, to make the choice be respected. (checkInput() sets m_destination accordingly)
     checkInput();
+#endif
 
     //an existing transfer has been specified and since ok was clicked, it was chosen to be overwritten
     if (m_existingTransfer) {
