@@ -52,6 +52,10 @@ Tray::Tray(MainWindow * parent)
 
     // filter middle mouse clicks to ask scheduler to paste URL
     connect(this, &Tray::secondaryActivateRequested, this, &Tray::slotActivated);
+
+    // show/hide the main window if requested
+    // KSystemTrayItem should handle this, but that apparenly doesn't work on Wayland (bug 389663)
+    connect(this, &Tray::activateRequested, this, &Tray::slotRestore);
 }
 
 
@@ -66,6 +70,16 @@ void Tray::slotActivated()
         NewTransferDialogHandler::showNewTransferDialog(QUrl(newtransfer));
 }
 
+// show/hide the main window if requested
+// KSystemTrayItem should handle this, but that apparenly doesn't work on Wayland (bug 389663)
+void Tray::slotRestore(bool active)
+{
+    if (active)
+        associatedWidget()->show();
+     else
+        associatedWidget()->hide();
+}
+
 // display a play icon when downloading and
 // switch between Active or Passive state
 void Tray::setDownloading( bool downloading )
